@@ -1,4 +1,4 @@
-from pyot.utils import run
+from pyot.utils import loop_run
 from pyot.models import val
 from syot.models import riot
 from .__core__ import SyotBaseObject
@@ -9,22 +9,23 @@ class SyotBase(SyotBaseObject):
 # from .match import Match, MatchHistory
 
 class Match(SyotBase, val.Match):
-    def get(self):
-        return run(super().get())
+    def get(self, **kwargs):
+        return loop_run(super().get(**kwargs))
 
 class MatchHistory(SyotBase, val.MatchHistory):
-    def get(self):
-        return run(super().get())
+    def get(self, **kwargs):
+        return loop_run(super().get(**kwargs))
 
 # from .content import Content
 
 class Content(SyotBase, val.Content):
-    def get(self):
-        return run(super().get())
+    def get(self, **kwargs):
+        return loop_run(super().get(**kwargs))
 
 SyotBase._bridges = {
     "Match": Match,
     "MatchHistory": MatchHistory,
     "Content": Content,
 }
+
 SyotBase._bridges.update(riot.SyotBase._bridges)
